# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SqlContainerArgs', 'SqlContainer']

@pulumi.input_type
class SqlContainerArgs:
    def __init__(__self__, *,
                 account_name: pulumi.Input[str],
                 database_name: pulumi.Input[str],
                 partition_key_paths: pulumi.Input[Sequence[pulumi.Input[str]]],
                 resource_group_name: pulumi.Input[str],
                 analytical_storage_ttl: Optional[pulumi.Input[int]] = None,
                 autoscale_settings: Optional[pulumi.Input['SqlContainerAutoscaleSettingsArgs']] = None,
                 conflict_resolution_policy: Optional[pulumi.Input['SqlContainerConflictResolutionPolicyArgs']] = None,
                 default_ttl: Optional[pulumi.Input[int]] = None,
                 indexing_policy: Optional[pulumi.Input['SqlContainerIndexingPolicyArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition_key_kind: Optional[pulumi.Input[str]] = None,
                 partition_key_version: Optional[pulumi.Input[int]] = None,
                 throughput: Optional[pulumi.Input[int]] = None,
                 unique_keys: Optional[pulumi.Input[Sequence[pulumi.Input['SqlContainerUniqueKeyArgs']]]] = None):
        """
        The set of arguments for constructing a SqlContainer resource.
        :param pulumi.Input[str] account_name: The name of the Cosmos DB Account to create the container within. Changing this forces a new resource to be created.
        :param pulumi.Input[str] database_name: The name of the Cosmos DB SQL Database to create the container within. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] partition_key_paths: A list of partition key paths. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the Cosmos DB SQL Container is created. Changing this forces a new resource to be created.
        :param pulumi.Input[int] analytical_storage_ttl: The default time to live of Analytical Storage for this SQL container. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        :param pulumi.Input['SqlContainerAutoscaleSettingsArgs'] autoscale_settings: An `autoscale_settings` block as defined below. This must be set upon database creation otherwise it cannot be updated without a manual destroy-apply.
               
               > **Note:** Switching between autoscale and manual throughput is not supported via this provider and must be completed via the Azure Portal and refreshed.
        :param pulumi.Input['SqlContainerConflictResolutionPolicyArgs'] conflict_resolution_policy: A `conflict_resolution_policy` blocks as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[int] default_ttl: The default time to live of SQL container. If missing, items are not expired automatically. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        :param pulumi.Input['SqlContainerIndexingPolicyArgs'] indexing_policy: An `indexing_policy` block as defined below.
        :param pulumi.Input[str] name: Specifies the name of the Cosmos DB SQL Container. Changing this forces a new resource to be created.
        :param pulumi.Input[str] partition_key_kind: Define a partition key kind. Possible values are `Hash` and `MultiHash`. Defaults to `Hash`. Changing this forces a new resource to be created.
        :param pulumi.Input[int] partition_key_version: Define a partition key version. Possible values are `1`and `2`. This should be set to `2` in order to use large partition keys.
               
               > **Note:** If `partition_key_version` is not specified when creating a new resource, you can update `partition_key_version` to `1`, updating to `2` forces a new resource to be created.
        :param pulumi.Input[int] throughput: The throughput of SQL container (RU/s). Must be set in increments of `100`. The minimum value is `400`. This must be set upon container creation otherwise it cannot be updated without a manual resource destroy-apply.
        :param pulumi.Input[Sequence[pulumi.Input['SqlContainerUniqueKeyArgs']]] unique_keys: One or more `unique_key` blocks as defined below. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "account_name", account_name)
        pulumi.set(__self__, "database_name", database_name)
        pulumi.set(__self__, "partition_key_paths", partition_key_paths)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if analytical_storage_ttl is not None:
            pulumi.set(__self__, "analytical_storage_ttl", analytical_storage_ttl)
        if autoscale_settings is not None:
            pulumi.set(__self__, "autoscale_settings", autoscale_settings)
        if conflict_resolution_policy is not None:
            pulumi.set(__self__, "conflict_resolution_policy", conflict_resolution_policy)
        if default_ttl is not None:
            pulumi.set(__self__, "default_ttl", default_ttl)
        if indexing_policy is not None:
            pulumi.set(__self__, "indexing_policy", indexing_policy)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition_key_kind is not None:
            pulumi.set(__self__, "partition_key_kind", partition_key_kind)
        if partition_key_version is not None:
            pulumi.set(__self__, "partition_key_version", partition_key_version)
        if throughput is not None:
            pulumi.set(__self__, "throughput", throughput)
        if unique_keys is not None:
            pulumi.set(__self__, "unique_keys", unique_keys)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Input[str]:
        """
        The name of the Cosmos DB Account to create the container within. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Input[str]:
        """
        The name of the Cosmos DB SQL Database to create the container within. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="partitionKeyPaths")
    def partition_key_paths(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        A list of partition key paths. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "partition_key_paths")

    @partition_key_paths.setter
    def partition_key_paths(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "partition_key_paths", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The name of the resource group in which the Cosmos DB SQL Container is created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="analyticalStorageTtl")
    def analytical_storage_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The default time to live of Analytical Storage for this SQL container. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        """
        return pulumi.get(self, "analytical_storage_ttl")

    @analytical_storage_ttl.setter
    def analytical_storage_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "analytical_storage_ttl", value)

    @property
    @pulumi.getter(name="autoscaleSettings")
    def autoscale_settings(self) -> Optional[pulumi.Input['SqlContainerAutoscaleSettingsArgs']]:
        """
        An `autoscale_settings` block as defined below. This must be set upon database creation otherwise it cannot be updated without a manual destroy-apply.

        > **Note:** Switching between autoscale and manual throughput is not supported via this provider and must be completed via the Azure Portal and refreshed.
        """
        return pulumi.get(self, "autoscale_settings")

    @autoscale_settings.setter
    def autoscale_settings(self, value: Optional[pulumi.Input['SqlContainerAutoscaleSettingsArgs']]):
        pulumi.set(self, "autoscale_settings", value)

    @property
    @pulumi.getter(name="conflictResolutionPolicy")
    def conflict_resolution_policy(self) -> Optional[pulumi.Input['SqlContainerConflictResolutionPolicyArgs']]:
        """
        A `conflict_resolution_policy` blocks as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "conflict_resolution_policy")

    @conflict_resolution_policy.setter
    def conflict_resolution_policy(self, value: Optional[pulumi.Input['SqlContainerConflictResolutionPolicyArgs']]):
        pulumi.set(self, "conflict_resolution_policy", value)

    @property
    @pulumi.getter(name="defaultTtl")
    def default_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The default time to live of SQL container. If missing, items are not expired automatically. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        """
        return pulumi.get(self, "default_ttl")

    @default_ttl.setter
    def default_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "default_ttl", value)

    @property
    @pulumi.getter(name="indexingPolicy")
    def indexing_policy(self) -> Optional[pulumi.Input['SqlContainerIndexingPolicyArgs']]:
        """
        An `indexing_policy` block as defined below.
        """
        return pulumi.get(self, "indexing_policy")

    @indexing_policy.setter
    def indexing_policy(self, value: Optional[pulumi.Input['SqlContainerIndexingPolicyArgs']]):
        pulumi.set(self, "indexing_policy", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Cosmos DB SQL Container. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="partitionKeyKind")
    def partition_key_kind(self) -> Optional[pulumi.Input[str]]:
        """
        Define a partition key kind. Possible values are `Hash` and `MultiHash`. Defaults to `Hash`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "partition_key_kind")

    @partition_key_kind.setter
    def partition_key_kind(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "partition_key_kind", value)

    @property
    @pulumi.getter(name="partitionKeyVersion")
    def partition_key_version(self) -> Optional[pulumi.Input[int]]:
        """
        Define a partition key version. Possible values are `1`and `2`. This should be set to `2` in order to use large partition keys.

        > **Note:** If `partition_key_version` is not specified when creating a new resource, you can update `partition_key_version` to `1`, updating to `2` forces a new resource to be created.
        """
        return pulumi.get(self, "partition_key_version")

    @partition_key_version.setter
    def partition_key_version(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "partition_key_version", value)

    @property
    @pulumi.getter
    def throughput(self) -> Optional[pulumi.Input[int]]:
        """
        The throughput of SQL container (RU/s). Must be set in increments of `100`. The minimum value is `400`. This must be set upon container creation otherwise it cannot be updated without a manual resource destroy-apply.
        """
        return pulumi.get(self, "throughput")

    @throughput.setter
    def throughput(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "throughput", value)

    @property
    @pulumi.getter(name="uniqueKeys")
    def unique_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SqlContainerUniqueKeyArgs']]]]:
        """
        One or more `unique_key` blocks as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "unique_keys")

    @unique_keys.setter
    def unique_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SqlContainerUniqueKeyArgs']]]]):
        pulumi.set(self, "unique_keys", value)


@pulumi.input_type
class _SqlContainerState:
    def __init__(__self__, *,
                 account_name: Optional[pulumi.Input[str]] = None,
                 analytical_storage_ttl: Optional[pulumi.Input[int]] = None,
                 autoscale_settings: Optional[pulumi.Input['SqlContainerAutoscaleSettingsArgs']] = None,
                 conflict_resolution_policy: Optional[pulumi.Input['SqlContainerConflictResolutionPolicyArgs']] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 default_ttl: Optional[pulumi.Input[int]] = None,
                 indexing_policy: Optional[pulumi.Input['SqlContainerIndexingPolicyArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition_key_kind: Optional[pulumi.Input[str]] = None,
                 partition_key_paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 partition_key_version: Optional[pulumi.Input[int]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 throughput: Optional[pulumi.Input[int]] = None,
                 unique_keys: Optional[pulumi.Input[Sequence[pulumi.Input['SqlContainerUniqueKeyArgs']]]] = None):
        """
        Input properties used for looking up and filtering SqlContainer resources.
        :param pulumi.Input[str] account_name: The name of the Cosmos DB Account to create the container within. Changing this forces a new resource to be created.
        :param pulumi.Input[int] analytical_storage_ttl: The default time to live of Analytical Storage for this SQL container. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        :param pulumi.Input['SqlContainerAutoscaleSettingsArgs'] autoscale_settings: An `autoscale_settings` block as defined below. This must be set upon database creation otherwise it cannot be updated without a manual destroy-apply.
               
               > **Note:** Switching between autoscale and manual throughput is not supported via this provider and must be completed via the Azure Portal and refreshed.
        :param pulumi.Input['SqlContainerConflictResolutionPolicyArgs'] conflict_resolution_policy: A `conflict_resolution_policy` blocks as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] database_name: The name of the Cosmos DB SQL Database to create the container within. Changing this forces a new resource to be created.
        :param pulumi.Input[int] default_ttl: The default time to live of SQL container. If missing, items are not expired automatically. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        :param pulumi.Input['SqlContainerIndexingPolicyArgs'] indexing_policy: An `indexing_policy` block as defined below.
        :param pulumi.Input[str] name: Specifies the name of the Cosmos DB SQL Container. Changing this forces a new resource to be created.
        :param pulumi.Input[str] partition_key_kind: Define a partition key kind. Possible values are `Hash` and `MultiHash`. Defaults to `Hash`. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] partition_key_paths: A list of partition key paths. Changing this forces a new resource to be created.
        :param pulumi.Input[int] partition_key_version: Define a partition key version. Possible values are `1`and `2`. This should be set to `2` in order to use large partition keys.
               
               > **Note:** If `partition_key_version` is not specified when creating a new resource, you can update `partition_key_version` to `1`, updating to `2` forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the Cosmos DB SQL Container is created. Changing this forces a new resource to be created.
        :param pulumi.Input[int] throughput: The throughput of SQL container (RU/s). Must be set in increments of `100`. The minimum value is `400`. This must be set upon container creation otherwise it cannot be updated without a manual resource destroy-apply.
        :param pulumi.Input[Sequence[pulumi.Input['SqlContainerUniqueKeyArgs']]] unique_keys: One or more `unique_key` blocks as defined below. Changing this forces a new resource to be created.
        """
        if account_name is not None:
            pulumi.set(__self__, "account_name", account_name)
        if analytical_storage_ttl is not None:
            pulumi.set(__self__, "analytical_storage_ttl", analytical_storage_ttl)
        if autoscale_settings is not None:
            pulumi.set(__self__, "autoscale_settings", autoscale_settings)
        if conflict_resolution_policy is not None:
            pulumi.set(__self__, "conflict_resolution_policy", conflict_resolution_policy)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if default_ttl is not None:
            pulumi.set(__self__, "default_ttl", default_ttl)
        if indexing_policy is not None:
            pulumi.set(__self__, "indexing_policy", indexing_policy)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition_key_kind is not None:
            pulumi.set(__self__, "partition_key_kind", partition_key_kind)
        if partition_key_paths is not None:
            pulumi.set(__self__, "partition_key_paths", partition_key_paths)
        if partition_key_version is not None:
            pulumi.set(__self__, "partition_key_version", partition_key_version)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if throughput is not None:
            pulumi.set(__self__, "throughput", throughput)
        if unique_keys is not None:
            pulumi.set(__self__, "unique_keys", unique_keys)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Cosmos DB Account to create the container within. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="analyticalStorageTtl")
    def analytical_storage_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The default time to live of Analytical Storage for this SQL container. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        """
        return pulumi.get(self, "analytical_storage_ttl")

    @analytical_storage_ttl.setter
    def analytical_storage_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "analytical_storage_ttl", value)

    @property
    @pulumi.getter(name="autoscaleSettings")
    def autoscale_settings(self) -> Optional[pulumi.Input['SqlContainerAutoscaleSettingsArgs']]:
        """
        An `autoscale_settings` block as defined below. This must be set upon database creation otherwise it cannot be updated without a manual destroy-apply.

        > **Note:** Switching between autoscale and manual throughput is not supported via this provider and must be completed via the Azure Portal and refreshed.
        """
        return pulumi.get(self, "autoscale_settings")

    @autoscale_settings.setter
    def autoscale_settings(self, value: Optional[pulumi.Input['SqlContainerAutoscaleSettingsArgs']]):
        pulumi.set(self, "autoscale_settings", value)

    @property
    @pulumi.getter(name="conflictResolutionPolicy")
    def conflict_resolution_policy(self) -> Optional[pulumi.Input['SqlContainerConflictResolutionPolicyArgs']]:
        """
        A `conflict_resolution_policy` blocks as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "conflict_resolution_policy")

    @conflict_resolution_policy.setter
    def conflict_resolution_policy(self, value: Optional[pulumi.Input['SqlContainerConflictResolutionPolicyArgs']]):
        pulumi.set(self, "conflict_resolution_policy", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Cosmos DB SQL Database to create the container within. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="defaultTtl")
    def default_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The default time to live of SQL container. If missing, items are not expired automatically. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        """
        return pulumi.get(self, "default_ttl")

    @default_ttl.setter
    def default_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "default_ttl", value)

    @property
    @pulumi.getter(name="indexingPolicy")
    def indexing_policy(self) -> Optional[pulumi.Input['SqlContainerIndexingPolicyArgs']]:
        """
        An `indexing_policy` block as defined below.
        """
        return pulumi.get(self, "indexing_policy")

    @indexing_policy.setter
    def indexing_policy(self, value: Optional[pulumi.Input['SqlContainerIndexingPolicyArgs']]):
        pulumi.set(self, "indexing_policy", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Cosmos DB SQL Container. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="partitionKeyKind")
    def partition_key_kind(self) -> Optional[pulumi.Input[str]]:
        """
        Define a partition key kind. Possible values are `Hash` and `MultiHash`. Defaults to `Hash`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "partition_key_kind")

    @partition_key_kind.setter
    def partition_key_kind(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "partition_key_kind", value)

    @property
    @pulumi.getter(name="partitionKeyPaths")
    def partition_key_paths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of partition key paths. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "partition_key_paths")

    @partition_key_paths.setter
    def partition_key_paths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "partition_key_paths", value)

    @property
    @pulumi.getter(name="partitionKeyVersion")
    def partition_key_version(self) -> Optional[pulumi.Input[int]]:
        """
        Define a partition key version. Possible values are `1`and `2`. This should be set to `2` in order to use large partition keys.

        > **Note:** If `partition_key_version` is not specified when creating a new resource, you can update `partition_key_version` to `1`, updating to `2` forces a new resource to be created.
        """
        return pulumi.get(self, "partition_key_version")

    @partition_key_version.setter
    def partition_key_version(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "partition_key_version", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource group in which the Cosmos DB SQL Container is created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def throughput(self) -> Optional[pulumi.Input[int]]:
        """
        The throughput of SQL container (RU/s). Must be set in increments of `100`. The minimum value is `400`. This must be set upon container creation otherwise it cannot be updated without a manual resource destroy-apply.
        """
        return pulumi.get(self, "throughput")

    @throughput.setter
    def throughput(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "throughput", value)

    @property
    @pulumi.getter(name="uniqueKeys")
    def unique_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SqlContainerUniqueKeyArgs']]]]:
        """
        One or more `unique_key` blocks as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "unique_keys")

    @unique_keys.setter
    def unique_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SqlContainerUniqueKeyArgs']]]]):
        pulumi.set(self, "unique_keys", value)


class SqlContainer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name: Optional[pulumi.Input[str]] = None,
                 analytical_storage_ttl: Optional[pulumi.Input[int]] = None,
                 autoscale_settings: Optional[pulumi.Input[Union['SqlContainerAutoscaleSettingsArgs', 'SqlContainerAutoscaleSettingsArgsDict']]] = None,
                 conflict_resolution_policy: Optional[pulumi.Input[Union['SqlContainerConflictResolutionPolicyArgs', 'SqlContainerConflictResolutionPolicyArgsDict']]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 default_ttl: Optional[pulumi.Input[int]] = None,
                 indexing_policy: Optional[pulumi.Input[Union['SqlContainerIndexingPolicyArgs', 'SqlContainerIndexingPolicyArgsDict']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition_key_kind: Optional[pulumi.Input[str]] = None,
                 partition_key_paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 partition_key_version: Optional[pulumi.Input[int]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 throughput: Optional[pulumi.Input[int]] = None,
                 unique_keys: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SqlContainerUniqueKeyArgs', 'SqlContainerUniqueKeyArgsDict']]]]] = None,
                 __props__=None):
        """
        Manages a SQL Container within a Cosmos DB Account.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.cosmosdb.get_account(name="tfex-cosmosdb-account",
            resource_group_name="tfex-cosmosdb-account-rg")
        example_sql_database = azure.cosmosdb.SqlDatabase("example",
            name="example-acsd",
            resource_group_name=example.resource_group_name,
            account_name=example.name)
        example_sql_container = azure.cosmosdb.SqlContainer("example",
            name="example-container",
            resource_group_name=example.resource_group_name,
            account_name=example.name,
            database_name=example_sql_database.name,
            partition_key_paths=["/definition/id"],
            partition_key_version=1,
            throughput=400,
            indexing_policy={
                "indexing_mode": "consistent",
                "included_paths": [
                    {
                        "path": "/*",
                    },
                    {
                        "path": "/included/?",
                    },
                ],
                "excluded_paths": [{
                    "path": "/excluded/?",
                }],
            },
            unique_keys=[{
                "paths": [
                    "/definition/idlong",
                    "/definition/idshort",
                ],
            }])
        ```

        ## Import

        Cosmos SQL Containers can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:cosmosdb/sqlContainer:SqlContainer example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.DocumentDB/databaseAccounts/account1/sqlDatabases/database1/containers/container1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_name: The name of the Cosmos DB Account to create the container within. Changing this forces a new resource to be created.
        :param pulumi.Input[int] analytical_storage_ttl: The default time to live of Analytical Storage for this SQL container. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        :param pulumi.Input[Union['SqlContainerAutoscaleSettingsArgs', 'SqlContainerAutoscaleSettingsArgsDict']] autoscale_settings: An `autoscale_settings` block as defined below. This must be set upon database creation otherwise it cannot be updated without a manual destroy-apply.
               
               > **Note:** Switching between autoscale and manual throughput is not supported via this provider and must be completed via the Azure Portal and refreshed.
        :param pulumi.Input[Union['SqlContainerConflictResolutionPolicyArgs', 'SqlContainerConflictResolutionPolicyArgsDict']] conflict_resolution_policy: A `conflict_resolution_policy` blocks as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] database_name: The name of the Cosmos DB SQL Database to create the container within. Changing this forces a new resource to be created.
        :param pulumi.Input[int] default_ttl: The default time to live of SQL container. If missing, items are not expired automatically. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        :param pulumi.Input[Union['SqlContainerIndexingPolicyArgs', 'SqlContainerIndexingPolicyArgsDict']] indexing_policy: An `indexing_policy` block as defined below.
        :param pulumi.Input[str] name: Specifies the name of the Cosmos DB SQL Container. Changing this forces a new resource to be created.
        :param pulumi.Input[str] partition_key_kind: Define a partition key kind. Possible values are `Hash` and `MultiHash`. Defaults to `Hash`. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] partition_key_paths: A list of partition key paths. Changing this forces a new resource to be created.
        :param pulumi.Input[int] partition_key_version: Define a partition key version. Possible values are `1`and `2`. This should be set to `2` in order to use large partition keys.
               
               > **Note:** If `partition_key_version` is not specified when creating a new resource, you can update `partition_key_version` to `1`, updating to `2` forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the Cosmos DB SQL Container is created. Changing this forces a new resource to be created.
        :param pulumi.Input[int] throughput: The throughput of SQL container (RU/s). Must be set in increments of `100`. The minimum value is `400`. This must be set upon container creation otherwise it cannot be updated without a manual resource destroy-apply.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SqlContainerUniqueKeyArgs', 'SqlContainerUniqueKeyArgsDict']]]] unique_keys: One or more `unique_key` blocks as defined below. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SqlContainerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a SQL Container within a Cosmos DB Account.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.cosmosdb.get_account(name="tfex-cosmosdb-account",
            resource_group_name="tfex-cosmosdb-account-rg")
        example_sql_database = azure.cosmosdb.SqlDatabase("example",
            name="example-acsd",
            resource_group_name=example.resource_group_name,
            account_name=example.name)
        example_sql_container = azure.cosmosdb.SqlContainer("example",
            name="example-container",
            resource_group_name=example.resource_group_name,
            account_name=example.name,
            database_name=example_sql_database.name,
            partition_key_paths=["/definition/id"],
            partition_key_version=1,
            throughput=400,
            indexing_policy={
                "indexing_mode": "consistent",
                "included_paths": [
                    {
                        "path": "/*",
                    },
                    {
                        "path": "/included/?",
                    },
                ],
                "excluded_paths": [{
                    "path": "/excluded/?",
                }],
            },
            unique_keys=[{
                "paths": [
                    "/definition/idlong",
                    "/definition/idshort",
                ],
            }])
        ```

        ## Import

        Cosmos SQL Containers can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:cosmosdb/sqlContainer:SqlContainer example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.DocumentDB/databaseAccounts/account1/sqlDatabases/database1/containers/container1
        ```

        :param str resource_name: The name of the resource.
        :param SqlContainerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SqlContainerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name: Optional[pulumi.Input[str]] = None,
                 analytical_storage_ttl: Optional[pulumi.Input[int]] = None,
                 autoscale_settings: Optional[pulumi.Input[Union['SqlContainerAutoscaleSettingsArgs', 'SqlContainerAutoscaleSettingsArgsDict']]] = None,
                 conflict_resolution_policy: Optional[pulumi.Input[Union['SqlContainerConflictResolutionPolicyArgs', 'SqlContainerConflictResolutionPolicyArgsDict']]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 default_ttl: Optional[pulumi.Input[int]] = None,
                 indexing_policy: Optional[pulumi.Input[Union['SqlContainerIndexingPolicyArgs', 'SqlContainerIndexingPolicyArgsDict']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition_key_kind: Optional[pulumi.Input[str]] = None,
                 partition_key_paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 partition_key_version: Optional[pulumi.Input[int]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 throughput: Optional[pulumi.Input[int]] = None,
                 unique_keys: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SqlContainerUniqueKeyArgs', 'SqlContainerUniqueKeyArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SqlContainerArgs.__new__(SqlContainerArgs)

            if account_name is None and not opts.urn:
                raise TypeError("Missing required property 'account_name'")
            __props__.__dict__["account_name"] = account_name
            __props__.__dict__["analytical_storage_ttl"] = analytical_storage_ttl
            __props__.__dict__["autoscale_settings"] = autoscale_settings
            __props__.__dict__["conflict_resolution_policy"] = conflict_resolution_policy
            if database_name is None and not opts.urn:
                raise TypeError("Missing required property 'database_name'")
            __props__.__dict__["database_name"] = database_name
            __props__.__dict__["default_ttl"] = default_ttl
            __props__.__dict__["indexing_policy"] = indexing_policy
            __props__.__dict__["name"] = name
            __props__.__dict__["partition_key_kind"] = partition_key_kind
            if partition_key_paths is None and not opts.urn:
                raise TypeError("Missing required property 'partition_key_paths'")
            __props__.__dict__["partition_key_paths"] = partition_key_paths
            __props__.__dict__["partition_key_version"] = partition_key_version
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["throughput"] = throughput
            __props__.__dict__["unique_keys"] = unique_keys
        super(SqlContainer, __self__).__init__(
            'azure:cosmosdb/sqlContainer:SqlContainer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_name: Optional[pulumi.Input[str]] = None,
            analytical_storage_ttl: Optional[pulumi.Input[int]] = None,
            autoscale_settings: Optional[pulumi.Input[Union['SqlContainerAutoscaleSettingsArgs', 'SqlContainerAutoscaleSettingsArgsDict']]] = None,
            conflict_resolution_policy: Optional[pulumi.Input[Union['SqlContainerConflictResolutionPolicyArgs', 'SqlContainerConflictResolutionPolicyArgsDict']]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            default_ttl: Optional[pulumi.Input[int]] = None,
            indexing_policy: Optional[pulumi.Input[Union['SqlContainerIndexingPolicyArgs', 'SqlContainerIndexingPolicyArgsDict']]] = None,
            name: Optional[pulumi.Input[str]] = None,
            partition_key_kind: Optional[pulumi.Input[str]] = None,
            partition_key_paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            partition_key_version: Optional[pulumi.Input[int]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            throughput: Optional[pulumi.Input[int]] = None,
            unique_keys: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SqlContainerUniqueKeyArgs', 'SqlContainerUniqueKeyArgsDict']]]]] = None) -> 'SqlContainer':
        """
        Get an existing SqlContainer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_name: The name of the Cosmos DB Account to create the container within. Changing this forces a new resource to be created.
        :param pulumi.Input[int] analytical_storage_ttl: The default time to live of Analytical Storage for this SQL container. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        :param pulumi.Input[Union['SqlContainerAutoscaleSettingsArgs', 'SqlContainerAutoscaleSettingsArgsDict']] autoscale_settings: An `autoscale_settings` block as defined below. This must be set upon database creation otherwise it cannot be updated without a manual destroy-apply.
               
               > **Note:** Switching between autoscale and manual throughput is not supported via this provider and must be completed via the Azure Portal and refreshed.
        :param pulumi.Input[Union['SqlContainerConflictResolutionPolicyArgs', 'SqlContainerConflictResolutionPolicyArgsDict']] conflict_resolution_policy: A `conflict_resolution_policy` blocks as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] database_name: The name of the Cosmos DB SQL Database to create the container within. Changing this forces a new resource to be created.
        :param pulumi.Input[int] default_ttl: The default time to live of SQL container. If missing, items are not expired automatically. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        :param pulumi.Input[Union['SqlContainerIndexingPolicyArgs', 'SqlContainerIndexingPolicyArgsDict']] indexing_policy: An `indexing_policy` block as defined below.
        :param pulumi.Input[str] name: Specifies the name of the Cosmos DB SQL Container. Changing this forces a new resource to be created.
        :param pulumi.Input[str] partition_key_kind: Define a partition key kind. Possible values are `Hash` and `MultiHash`. Defaults to `Hash`. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] partition_key_paths: A list of partition key paths. Changing this forces a new resource to be created.
        :param pulumi.Input[int] partition_key_version: Define a partition key version. Possible values are `1`and `2`. This should be set to `2` in order to use large partition keys.
               
               > **Note:** If `partition_key_version` is not specified when creating a new resource, you can update `partition_key_version` to `1`, updating to `2` forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the Cosmos DB SQL Container is created. Changing this forces a new resource to be created.
        :param pulumi.Input[int] throughput: The throughput of SQL container (RU/s). Must be set in increments of `100`. The minimum value is `400`. This must be set upon container creation otherwise it cannot be updated without a manual resource destroy-apply.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SqlContainerUniqueKeyArgs', 'SqlContainerUniqueKeyArgsDict']]]] unique_keys: One or more `unique_key` blocks as defined below. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SqlContainerState.__new__(_SqlContainerState)

        __props__.__dict__["account_name"] = account_name
        __props__.__dict__["analytical_storage_ttl"] = analytical_storage_ttl
        __props__.__dict__["autoscale_settings"] = autoscale_settings
        __props__.__dict__["conflict_resolution_policy"] = conflict_resolution_policy
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["default_ttl"] = default_ttl
        __props__.__dict__["indexing_policy"] = indexing_policy
        __props__.__dict__["name"] = name
        __props__.__dict__["partition_key_kind"] = partition_key_kind
        __props__.__dict__["partition_key_paths"] = partition_key_paths
        __props__.__dict__["partition_key_version"] = partition_key_version
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["throughput"] = throughput
        __props__.__dict__["unique_keys"] = unique_keys
        return SqlContainer(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Output[str]:
        """
        The name of the Cosmos DB Account to create the container within. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="analyticalStorageTtl")
    def analytical_storage_ttl(self) -> pulumi.Output[Optional[int]]:
        """
        The default time to live of Analytical Storage for this SQL container. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        """
        return pulumi.get(self, "analytical_storage_ttl")

    @property
    @pulumi.getter(name="autoscaleSettings")
    def autoscale_settings(self) -> pulumi.Output[Optional['outputs.SqlContainerAutoscaleSettings']]:
        """
        An `autoscale_settings` block as defined below. This must be set upon database creation otherwise it cannot be updated without a manual destroy-apply.

        > **Note:** Switching between autoscale and manual throughput is not supported via this provider and must be completed via the Azure Portal and refreshed.
        """
        return pulumi.get(self, "autoscale_settings")

    @property
    @pulumi.getter(name="conflictResolutionPolicy")
    def conflict_resolution_policy(self) -> pulumi.Output['outputs.SqlContainerConflictResolutionPolicy']:
        """
        A `conflict_resolution_policy` blocks as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "conflict_resolution_policy")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[str]:
        """
        The name of the Cosmos DB SQL Database to create the container within. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter(name="defaultTtl")
    def default_ttl(self) -> pulumi.Output[Optional[int]]:
        """
        The default time to live of SQL container. If missing, items are not expired automatically. If present and the value is set to `-1`, it is equal to infinity, and items don’t expire by default. If present and the value is set to some number `n` – items will expire `n` seconds after their last modified time.
        """
        return pulumi.get(self, "default_ttl")

    @property
    @pulumi.getter(name="indexingPolicy")
    def indexing_policy(self) -> pulumi.Output['outputs.SqlContainerIndexingPolicy']:
        """
        An `indexing_policy` block as defined below.
        """
        return pulumi.get(self, "indexing_policy")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Specifies the name of the Cosmos DB SQL Container. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="partitionKeyKind")
    def partition_key_kind(self) -> pulumi.Output[Optional[str]]:
        """
        Define a partition key kind. Possible values are `Hash` and `MultiHash`. Defaults to `Hash`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "partition_key_kind")

    @property
    @pulumi.getter(name="partitionKeyPaths")
    def partition_key_paths(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of partition key paths. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "partition_key_paths")

    @property
    @pulumi.getter(name="partitionKeyVersion")
    def partition_key_version(self) -> pulumi.Output[Optional[int]]:
        """
        Define a partition key version. Possible values are `1`and `2`. This should be set to `2` in order to use large partition keys.

        > **Note:** If `partition_key_version` is not specified when creating a new resource, you can update `partition_key_version` to `1`, updating to `2` forces a new resource to be created.
        """
        return pulumi.get(self, "partition_key_version")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        The name of the resource group in which the Cosmos DB SQL Container is created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def throughput(self) -> pulumi.Output[int]:
        """
        The throughput of SQL container (RU/s). Must be set in increments of `100`. The minimum value is `400`. This must be set upon container creation otherwise it cannot be updated without a manual resource destroy-apply.
        """
        return pulumi.get(self, "throughput")

    @property
    @pulumi.getter(name="uniqueKeys")
    def unique_keys(self) -> pulumi.Output[Optional[Sequence['outputs.SqlContainerUniqueKey']]]:
        """
        One or more `unique_key` blocks as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "unique_keys")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetEnterpriseDatabaseResult',
    'AwaitableGetEnterpriseDatabaseResult',
    'get_enterprise_database',
    'get_enterprise_database_output',
]

@pulumi.output_type
class GetEnterpriseDatabaseResult:
    """
    A collection of values returned by getEnterpriseDatabase.
    """
    def __init__(__self__, cluster_id=None, id=None, linked_database_group_nickname=None, linked_database_ids=None, name=None, primary_access_key=None, secondary_access_key=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if linked_database_group_nickname and not isinstance(linked_database_group_nickname, str):
            raise TypeError("Expected argument 'linked_database_group_nickname' to be a str")
        pulumi.set(__self__, "linked_database_group_nickname", linked_database_group_nickname)
        if linked_database_ids and not isinstance(linked_database_ids, list):
            raise TypeError("Expected argument 'linked_database_ids' to be a list")
        pulumi.set(__self__, "linked_database_ids", linked_database_ids)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if primary_access_key and not isinstance(primary_access_key, str):
            raise TypeError("Expected argument 'primary_access_key' to be a str")
        pulumi.set(__self__, "primary_access_key", primary_access_key)
        if secondary_access_key and not isinstance(secondary_access_key, str):
            raise TypeError("Expected argument 'secondary_access_key' to be a str")
        pulumi.set(__self__, "secondary_access_key", secondary_access_key)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> str:
        """
        The Redis Enterprise Cluster ID that is hosting the Redis Enterprise Database.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="linkedDatabaseGroupNickname")
    def linked_database_group_nickname(self) -> str:
        """
        The Linked Database Group Nickname for the Redis Enterprise Database instance.
        """
        return pulumi.get(self, "linked_database_group_nickname")

    @property
    @pulumi.getter(name="linkedDatabaseIds")
    def linked_database_ids(self) -> Sequence[str]:
        """
        The Linked Database list for the Redis Enterprise Database instance.
        """
        return pulumi.get(self, "linked_database_ids")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The Redis Enterprise Database name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="primaryAccessKey")
    def primary_access_key(self) -> str:
        """
        The Primary Access Key for the Redis Enterprise Database instance.
        """
        return pulumi.get(self, "primary_access_key")

    @property
    @pulumi.getter(name="secondaryAccessKey")
    def secondary_access_key(self) -> str:
        """
        The Secondary Access Key for the Redis Enterprise Database instance.
        """
        return pulumi.get(self, "secondary_access_key")


class AwaitableGetEnterpriseDatabaseResult(GetEnterpriseDatabaseResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnterpriseDatabaseResult(
            cluster_id=self.cluster_id,
            id=self.id,
            linked_database_group_nickname=self.linked_database_group_nickname,
            linked_database_ids=self.linked_database_ids,
            name=self.name,
            primary_access_key=self.primary_access_key,
            secondary_access_key=self.secondary_access_key)


def get_enterprise_database(cluster_id: Optional[str] = None,
                            name: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnterpriseDatabaseResult:
    """
    Use this data source to access information about an existing Redis Enterprise Database


    :param str cluster_id: The resource ID of Redis Enterprise Cluster which hosts the Redis Enterprise Database instance.
    :param str name: The name of the Redis Enterprise Database.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:redis/getEnterpriseDatabase:getEnterpriseDatabase', __args__, opts=opts, typ=GetEnterpriseDatabaseResult).value

    return AwaitableGetEnterpriseDatabaseResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        linked_database_group_nickname=pulumi.get(__ret__, 'linked_database_group_nickname'),
        linked_database_ids=pulumi.get(__ret__, 'linked_database_ids'),
        name=pulumi.get(__ret__, 'name'),
        primary_access_key=pulumi.get(__ret__, 'primary_access_key'),
        secondary_access_key=pulumi.get(__ret__, 'secondary_access_key'))
def get_enterprise_database_output(cluster_id: Optional[pulumi.Input[str]] = None,
                                   name: Optional[pulumi.Input[str]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEnterpriseDatabaseResult]:
    """
    Use this data source to access information about an existing Redis Enterprise Database


    :param str cluster_id: The resource ID of Redis Enterprise Cluster which hosts the Redis Enterprise Database instance.
    :param str name: The name of the Redis Enterprise Database.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:redis/getEnterpriseDatabase:getEnterpriseDatabase', __args__, opts=opts, typ=GetEnterpriseDatabaseResult)
    return __ret__.apply(lambda __response__: GetEnterpriseDatabaseResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        id=pulumi.get(__response__, 'id'),
        linked_database_group_nickname=pulumi.get(__response__, 'linked_database_group_nickname'),
        linked_database_ids=pulumi.get(__response__, 'linked_database_ids'),
        name=pulumi.get(__response__, 'name'),
        primary_access_key=pulumi.get(__response__, 'primary_access_key'),
        secondary_access_key=pulumi.get(__response__, 'secondary_access_key')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ActiveRoleAssignmentScheduleArgs',
    'ActiveRoleAssignmentScheduleArgsDict',
    'ActiveRoleAssignmentScheduleExpirationArgs',
    'ActiveRoleAssignmentScheduleExpirationArgsDict',
    'ActiveRoleAssignmentTicketArgs',
    'ActiveRoleAssignmentTicketArgsDict',
    'EligibleRoleAssignmentScheduleArgs',
    'EligibleRoleAssignmentScheduleArgsDict',
    'EligibleRoleAssignmentScheduleExpirationArgs',
    'EligibleRoleAssignmentScheduleExpirationArgsDict',
    'EligibleRoleAssignmentTicketArgs',
    'EligibleRoleAssignmentTicketArgsDict',
    'RoleManagementPolicyActivationRulesArgs',
    'RoleManagementPolicyActivationRulesArgsDict',
    'RoleManagementPolicyActivationRulesApprovalStageArgs',
    'RoleManagementPolicyActivationRulesApprovalStageArgsDict',
    'RoleManagementPolicyActivationRulesApprovalStagePrimaryApproverArgs',
    'RoleManagementPolicyActivationRulesApprovalStagePrimaryApproverArgsDict',
    'RoleManagementPolicyActiveAssignmentRulesArgs',
    'RoleManagementPolicyActiveAssignmentRulesArgsDict',
    'RoleManagementPolicyEligibleAssignmentRulesArgs',
    'RoleManagementPolicyEligibleAssignmentRulesArgsDict',
    'RoleManagementPolicyNotificationRulesArgs',
    'RoleManagementPolicyNotificationRulesArgsDict',
    'RoleManagementPolicyNotificationRulesActiveAssignmentsArgs',
    'RoleManagementPolicyNotificationRulesActiveAssignmentsArgsDict',
    'RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotificationsArgs',
    'RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotificationsArgsDict',
    'RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotificationsArgs',
    'RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotificationsArgsDict',
    'RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotificationsArgs',
    'RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotificationsArgsDict',
    'RoleManagementPolicyNotificationRulesEligibleActivationsArgs',
    'RoleManagementPolicyNotificationRulesEligibleActivationsArgsDict',
    'RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotificationsArgs',
    'RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotificationsArgsDict',
    'RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotificationsArgs',
    'RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotificationsArgsDict',
    'RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotificationsArgs',
    'RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotificationsArgsDict',
    'RoleManagementPolicyNotificationRulesEligibleAssignmentsArgs',
    'RoleManagementPolicyNotificationRulesEligibleAssignmentsArgsDict',
    'RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotificationsArgs',
    'RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotificationsArgsDict',
    'RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotificationsArgs',
    'RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotificationsArgsDict',
    'RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotificationsArgs',
    'RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotificationsArgsDict',
]

MYPY = False

if not MYPY:
    class ActiveRoleAssignmentScheduleArgsDict(TypedDict):
        expiration: NotRequired[pulumi.Input['ActiveRoleAssignmentScheduleExpirationArgsDict']]
        """
        An `expiration` block as defined above.
        """
        start_date_time: NotRequired[pulumi.Input[str]]
        """
        The start date/time of the role assignment. Changing this forces a new resource to be created.
        """
elif False:
    ActiveRoleAssignmentScheduleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ActiveRoleAssignmentScheduleArgs:
    def __init__(__self__, *,
                 expiration: Optional[pulumi.Input['ActiveRoleAssignmentScheduleExpirationArgs']] = None,
                 start_date_time: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input['ActiveRoleAssignmentScheduleExpirationArgs'] expiration: An `expiration` block as defined above.
        :param pulumi.Input[str] start_date_time: The start date/time of the role assignment. Changing this forces a new resource to be created.
        """
        if expiration is not None:
            pulumi.set(__self__, "expiration", expiration)
        if start_date_time is not None:
            pulumi.set(__self__, "start_date_time", start_date_time)

    @property
    @pulumi.getter
    def expiration(self) -> Optional[pulumi.Input['ActiveRoleAssignmentScheduleExpirationArgs']]:
        """
        An `expiration` block as defined above.
        """
        return pulumi.get(self, "expiration")

    @expiration.setter
    def expiration(self, value: Optional[pulumi.Input['ActiveRoleAssignmentScheduleExpirationArgs']]):
        pulumi.set(self, "expiration", value)

    @property
    @pulumi.getter(name="startDateTime")
    def start_date_time(self) -> Optional[pulumi.Input[str]]:
        """
        The start date/time of the role assignment. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "start_date_time")

    @start_date_time.setter
    def start_date_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_date_time", value)


if not MYPY:
    class ActiveRoleAssignmentScheduleExpirationArgsDict(TypedDict):
        duration_days: NotRequired[pulumi.Input[int]]
        """
        The duration of the role assignment in days. Changing this forces a new resource to be created.
        """
        duration_hours: NotRequired[pulumi.Input[int]]
        """
        The duration of the role assignment in hours. Changing this forces a new resource to be created.
        """
        end_date_time: NotRequired[pulumi.Input[str]]
        """
        The end date/time of the role assignment. Changing this forces a new resource to be created.

        > Note: Only one of `duration_days`, `duration_hours` or `end_date_time` should be specified.
        """
elif False:
    ActiveRoleAssignmentScheduleExpirationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ActiveRoleAssignmentScheduleExpirationArgs:
    def __init__(__self__, *,
                 duration_days: Optional[pulumi.Input[int]] = None,
                 duration_hours: Optional[pulumi.Input[int]] = None,
                 end_date_time: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[int] duration_days: The duration of the role assignment in days. Changing this forces a new resource to be created.
        :param pulumi.Input[int] duration_hours: The duration of the role assignment in hours. Changing this forces a new resource to be created.
        :param pulumi.Input[str] end_date_time: The end date/time of the role assignment. Changing this forces a new resource to be created.
               
               > Note: Only one of `duration_days`, `duration_hours` or `end_date_time` should be specified.
        """
        if duration_days is not None:
            pulumi.set(__self__, "duration_days", duration_days)
        if duration_hours is not None:
            pulumi.set(__self__, "duration_hours", duration_hours)
        if end_date_time is not None:
            pulumi.set(__self__, "end_date_time", end_date_time)

    @property
    @pulumi.getter(name="durationDays")
    def duration_days(self) -> Optional[pulumi.Input[int]]:
        """
        The duration of the role assignment in days. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration_days")

    @duration_days.setter
    def duration_days(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration_days", value)

    @property
    @pulumi.getter(name="durationHours")
    def duration_hours(self) -> Optional[pulumi.Input[int]]:
        """
        The duration of the role assignment in hours. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration_hours")

    @duration_hours.setter
    def duration_hours(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration_hours", value)

    @property
    @pulumi.getter(name="endDateTime")
    def end_date_time(self) -> Optional[pulumi.Input[str]]:
        """
        The end date/time of the role assignment. Changing this forces a new resource to be created.

        > Note: Only one of `duration_days`, `duration_hours` or `end_date_time` should be specified.
        """
        return pulumi.get(self, "end_date_time")

    @end_date_time.setter
    def end_date_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "end_date_time", value)


if not MYPY:
    class ActiveRoleAssignmentTicketArgsDict(TypedDict):
        number: NotRequired[pulumi.Input[str]]
        """
        User-supplied ticket number to be included with the request. Changing this forces a new resource to be created.
        """
        system: NotRequired[pulumi.Input[str]]
        """
        User-supplied ticket system name to be included with the request. Changing this forces a new resource to be created.
        """
elif False:
    ActiveRoleAssignmentTicketArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ActiveRoleAssignmentTicketArgs:
    def __init__(__self__, *,
                 number: Optional[pulumi.Input[str]] = None,
                 system: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] number: User-supplied ticket number to be included with the request. Changing this forces a new resource to be created.
        :param pulumi.Input[str] system: User-supplied ticket system name to be included with the request. Changing this forces a new resource to be created.
        """
        if number is not None:
            pulumi.set(__self__, "number", number)
        if system is not None:
            pulumi.set(__self__, "system", system)

    @property
    @pulumi.getter
    def number(self) -> Optional[pulumi.Input[str]]:
        """
        User-supplied ticket number to be included with the request. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "number")

    @number.setter
    def number(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "number", value)

    @property
    @pulumi.getter
    def system(self) -> Optional[pulumi.Input[str]]:
        """
        User-supplied ticket system name to be included with the request. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "system")

    @system.setter
    def system(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "system", value)


if not MYPY:
    class EligibleRoleAssignmentScheduleArgsDict(TypedDict):
        expiration: NotRequired[pulumi.Input['EligibleRoleAssignmentScheduleExpirationArgsDict']]
        """
        An `expiration` block as defined above.
        """
        start_date_time: NotRequired[pulumi.Input[str]]
        """
        The start date/time of the role assignment. Changing this forces a new resource to be created.
        """
elif False:
    EligibleRoleAssignmentScheduleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class EligibleRoleAssignmentScheduleArgs:
    def __init__(__self__, *,
                 expiration: Optional[pulumi.Input['EligibleRoleAssignmentScheduleExpirationArgs']] = None,
                 start_date_time: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input['EligibleRoleAssignmentScheduleExpirationArgs'] expiration: An `expiration` block as defined above.
        :param pulumi.Input[str] start_date_time: The start date/time of the role assignment. Changing this forces a new resource to be created.
        """
        if expiration is not None:
            pulumi.set(__self__, "expiration", expiration)
        if start_date_time is not None:
            pulumi.set(__self__, "start_date_time", start_date_time)

    @property
    @pulumi.getter
    def expiration(self) -> Optional[pulumi.Input['EligibleRoleAssignmentScheduleExpirationArgs']]:
        """
        An `expiration` block as defined above.
        """
        return pulumi.get(self, "expiration")

    @expiration.setter
    def expiration(self, value: Optional[pulumi.Input['EligibleRoleAssignmentScheduleExpirationArgs']]):
        pulumi.set(self, "expiration", value)

    @property
    @pulumi.getter(name="startDateTime")
    def start_date_time(self) -> Optional[pulumi.Input[str]]:
        """
        The start date/time of the role assignment. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "start_date_time")

    @start_date_time.setter
    def start_date_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_date_time", value)


if not MYPY:
    class EligibleRoleAssignmentScheduleExpirationArgsDict(TypedDict):
        duration_days: NotRequired[pulumi.Input[int]]
        """
        The duration of the role assignment in days. Changing this forces a new resource to be created.
        """
        duration_hours: NotRequired[pulumi.Input[int]]
        """
        The duration of the role assignment in hours. Changing this forces a new resource to be created.
        """
        end_date_time: NotRequired[pulumi.Input[str]]
        """
        The end date/time of the role assignment. Changing this forces a new resource to be created.

        > Note: Only one of `duration_days`, `duration_hours` or `end_date_time` should be specified.
        """
elif False:
    EligibleRoleAssignmentScheduleExpirationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class EligibleRoleAssignmentScheduleExpirationArgs:
    def __init__(__self__, *,
                 duration_days: Optional[pulumi.Input[int]] = None,
                 duration_hours: Optional[pulumi.Input[int]] = None,
                 end_date_time: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[int] duration_days: The duration of the role assignment in days. Changing this forces a new resource to be created.
        :param pulumi.Input[int] duration_hours: The duration of the role assignment in hours. Changing this forces a new resource to be created.
        :param pulumi.Input[str] end_date_time: The end date/time of the role assignment. Changing this forces a new resource to be created.
               
               > Note: Only one of `duration_days`, `duration_hours` or `end_date_time` should be specified.
        """
        if duration_days is not None:
            pulumi.set(__self__, "duration_days", duration_days)
        if duration_hours is not None:
            pulumi.set(__self__, "duration_hours", duration_hours)
        if end_date_time is not None:
            pulumi.set(__self__, "end_date_time", end_date_time)

    @property
    @pulumi.getter(name="durationDays")
    def duration_days(self) -> Optional[pulumi.Input[int]]:
        """
        The duration of the role assignment in days. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration_days")

    @duration_days.setter
    def duration_days(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration_days", value)

    @property
    @pulumi.getter(name="durationHours")
    def duration_hours(self) -> Optional[pulumi.Input[int]]:
        """
        The duration of the role assignment in hours. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration_hours")

    @duration_hours.setter
    def duration_hours(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration_hours", value)

    @property
    @pulumi.getter(name="endDateTime")
    def end_date_time(self) -> Optional[pulumi.Input[str]]:
        """
        The end date/time of the role assignment. Changing this forces a new resource to be created.

        > Note: Only one of `duration_days`, `duration_hours` or `end_date_time` should be specified.
        """
        return pulumi.get(self, "end_date_time")

    @end_date_time.setter
    def end_date_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "end_date_time", value)


if not MYPY:
    class EligibleRoleAssignmentTicketArgsDict(TypedDict):
        number: NotRequired[pulumi.Input[str]]
        """
        User-supplied ticket number to be included with the request. Changing this forces a new resource to be created.
        """
        system: NotRequired[pulumi.Input[str]]
        """
        User-supplied ticket system name to be included with the request. Changing this forces a new resource to be created.
        """
elif False:
    EligibleRoleAssignmentTicketArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class EligibleRoleAssignmentTicketArgs:
    def __init__(__self__, *,
                 number: Optional[pulumi.Input[str]] = None,
                 system: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] number: User-supplied ticket number to be included with the request. Changing this forces a new resource to be created.
        :param pulumi.Input[str] system: User-supplied ticket system name to be included with the request. Changing this forces a new resource to be created.
        """
        if number is not None:
            pulumi.set(__self__, "number", number)
        if system is not None:
            pulumi.set(__self__, "system", system)

    @property
    @pulumi.getter
    def number(self) -> Optional[pulumi.Input[str]]:
        """
        User-supplied ticket number to be included with the request. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "number")

    @number.setter
    def number(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "number", value)

    @property
    @pulumi.getter
    def system(self) -> Optional[pulumi.Input[str]]:
        """
        User-supplied ticket system name to be included with the request. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "system")

    @system.setter
    def system(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "system", value)


if not MYPY:
    class RoleManagementPolicyActivationRulesArgsDict(TypedDict):
        approval_stage: NotRequired[pulumi.Input['RoleManagementPolicyActivationRulesApprovalStageArgsDict']]
        """
        An `approval_stage` block as defined below.
        """
        maximum_duration: NotRequired[pulumi.Input[str]]
        """
        The maximum length of time an activated role can be valid, in an ISO8601 Duration format (e.g. `PT8H`). Valid range is `PT30M` to `PT23H30M`, in 30 minute increments, or `PT1D`.
        """
        require_approval: NotRequired[pulumi.Input[bool]]
        """
        Is approval required for activation. If `true` an `approval_stage` block must be provided.
        """
        require_justification: NotRequired[pulumi.Input[bool]]
        """
        Is a justification required during activation of the role.
        """
        require_multifactor_authentication: NotRequired[pulumi.Input[bool]]
        """
        Is multi-factor authentication required to activate the role. Conflicts with `required_conditional_access_authentication_context`.
        """
        require_ticket_info: NotRequired[pulumi.Input[bool]]
        """
        Is ticket information requrired during activation of the role.
        """
        required_conditional_access_authentication_context: NotRequired[pulumi.Input[str]]
        """
        The Entra ID Conditional Access context that must be present for activation. Conflicts with `require_multifactor_authentication`.
        """
elif False:
    RoleManagementPolicyActivationRulesArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyActivationRulesArgs:
    def __init__(__self__, *,
                 approval_stage: Optional[pulumi.Input['RoleManagementPolicyActivationRulesApprovalStageArgs']] = None,
                 maximum_duration: Optional[pulumi.Input[str]] = None,
                 require_approval: Optional[pulumi.Input[bool]] = None,
                 require_justification: Optional[pulumi.Input[bool]] = None,
                 require_multifactor_authentication: Optional[pulumi.Input[bool]] = None,
                 require_ticket_info: Optional[pulumi.Input[bool]] = None,
                 required_conditional_access_authentication_context: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input['RoleManagementPolicyActivationRulesApprovalStageArgs'] approval_stage: An `approval_stage` block as defined below.
        :param pulumi.Input[str] maximum_duration: The maximum length of time an activated role can be valid, in an ISO8601 Duration format (e.g. `PT8H`). Valid range is `PT30M` to `PT23H30M`, in 30 minute increments, or `PT1D`.
        :param pulumi.Input[bool] require_approval: Is approval required for activation. If `true` an `approval_stage` block must be provided.
        :param pulumi.Input[bool] require_justification: Is a justification required during activation of the role.
        :param pulumi.Input[bool] require_multifactor_authentication: Is multi-factor authentication required to activate the role. Conflicts with `required_conditional_access_authentication_context`.
        :param pulumi.Input[bool] require_ticket_info: Is ticket information requrired during activation of the role.
        :param pulumi.Input[str] required_conditional_access_authentication_context: The Entra ID Conditional Access context that must be present for activation. Conflicts with `require_multifactor_authentication`.
        """
        if approval_stage is not None:
            pulumi.set(__self__, "approval_stage", approval_stage)
        if maximum_duration is not None:
            pulumi.set(__self__, "maximum_duration", maximum_duration)
        if require_approval is not None:
            pulumi.set(__self__, "require_approval", require_approval)
        if require_justification is not None:
            pulumi.set(__self__, "require_justification", require_justification)
        if require_multifactor_authentication is not None:
            pulumi.set(__self__, "require_multifactor_authentication", require_multifactor_authentication)
        if require_ticket_info is not None:
            pulumi.set(__self__, "require_ticket_info", require_ticket_info)
        if required_conditional_access_authentication_context is not None:
            pulumi.set(__self__, "required_conditional_access_authentication_context", required_conditional_access_authentication_context)

    @property
    @pulumi.getter(name="approvalStage")
    def approval_stage(self) -> Optional[pulumi.Input['RoleManagementPolicyActivationRulesApprovalStageArgs']]:
        """
        An `approval_stage` block as defined below.
        """
        return pulumi.get(self, "approval_stage")

    @approval_stage.setter
    def approval_stage(self, value: Optional[pulumi.Input['RoleManagementPolicyActivationRulesApprovalStageArgs']]):
        pulumi.set(self, "approval_stage", value)

    @property
    @pulumi.getter(name="maximumDuration")
    def maximum_duration(self) -> Optional[pulumi.Input[str]]:
        """
        The maximum length of time an activated role can be valid, in an ISO8601 Duration format (e.g. `PT8H`). Valid range is `PT30M` to `PT23H30M`, in 30 minute increments, or `PT1D`.
        """
        return pulumi.get(self, "maximum_duration")

    @maximum_duration.setter
    def maximum_duration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "maximum_duration", value)

    @property
    @pulumi.getter(name="requireApproval")
    def require_approval(self) -> Optional[pulumi.Input[bool]]:
        """
        Is approval required for activation. If `true` an `approval_stage` block must be provided.
        """
        return pulumi.get(self, "require_approval")

    @require_approval.setter
    def require_approval(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "require_approval", value)

    @property
    @pulumi.getter(name="requireJustification")
    def require_justification(self) -> Optional[pulumi.Input[bool]]:
        """
        Is a justification required during activation of the role.
        """
        return pulumi.get(self, "require_justification")

    @require_justification.setter
    def require_justification(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "require_justification", value)

    @property
    @pulumi.getter(name="requireMultifactorAuthentication")
    def require_multifactor_authentication(self) -> Optional[pulumi.Input[bool]]:
        """
        Is multi-factor authentication required to activate the role. Conflicts with `required_conditional_access_authentication_context`.
        """
        return pulumi.get(self, "require_multifactor_authentication")

    @require_multifactor_authentication.setter
    def require_multifactor_authentication(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "require_multifactor_authentication", value)

    @property
    @pulumi.getter(name="requireTicketInfo")
    def require_ticket_info(self) -> Optional[pulumi.Input[bool]]:
        """
        Is ticket information requrired during activation of the role.
        """
        return pulumi.get(self, "require_ticket_info")

    @require_ticket_info.setter
    def require_ticket_info(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "require_ticket_info", value)

    @property
    @pulumi.getter(name="requiredConditionalAccessAuthenticationContext")
    def required_conditional_access_authentication_context(self) -> Optional[pulumi.Input[str]]:
        """
        The Entra ID Conditional Access context that must be present for activation. Conflicts with `require_multifactor_authentication`.
        """
        return pulumi.get(self, "required_conditional_access_authentication_context")

    @required_conditional_access_authentication_context.setter
    def required_conditional_access_authentication_context(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "required_conditional_access_authentication_context", value)


if not MYPY:
    class RoleManagementPolicyActivationRulesApprovalStageArgsDict(TypedDict):
        primary_approvers: pulumi.Input[Sequence[pulumi.Input['RoleManagementPolicyActivationRulesApprovalStagePrimaryApproverArgsDict']]]
        """
        The IDs of the users or groups who can approve the activation
        """
elif False:
    RoleManagementPolicyActivationRulesApprovalStageArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyActivationRulesApprovalStageArgs:
    def __init__(__self__, *,
                 primary_approvers: pulumi.Input[Sequence[pulumi.Input['RoleManagementPolicyActivationRulesApprovalStagePrimaryApproverArgs']]]):
        """
        :param pulumi.Input[Sequence[pulumi.Input['RoleManagementPolicyActivationRulesApprovalStagePrimaryApproverArgs']]] primary_approvers: The IDs of the users or groups who can approve the activation
        """
        pulumi.set(__self__, "primary_approvers", primary_approvers)

    @property
    @pulumi.getter(name="primaryApprovers")
    def primary_approvers(self) -> pulumi.Input[Sequence[pulumi.Input['RoleManagementPolicyActivationRulesApprovalStagePrimaryApproverArgs']]]:
        """
        The IDs of the users or groups who can approve the activation
        """
        return pulumi.get(self, "primary_approvers")

    @primary_approvers.setter
    def primary_approvers(self, value: pulumi.Input[Sequence[pulumi.Input['RoleManagementPolicyActivationRulesApprovalStagePrimaryApproverArgs']]]):
        pulumi.set(self, "primary_approvers", value)


if not MYPY:
    class RoleManagementPolicyActivationRulesApprovalStagePrimaryApproverArgsDict(TypedDict):
        object_id: pulumi.Input[str]
        """
        The ID of the object which will act as an approver.
        """
        type: pulumi.Input[str]
        """
        The type of object acting as an approver. Possible options are `User` and `Group`.
        """
elif False:
    RoleManagementPolicyActivationRulesApprovalStagePrimaryApproverArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyActivationRulesApprovalStagePrimaryApproverArgs:
    def __init__(__self__, *,
                 object_id: pulumi.Input[str],
                 type: pulumi.Input[str]):
        """
        :param pulumi.Input[str] object_id: The ID of the object which will act as an approver.
        :param pulumi.Input[str] type: The type of object acting as an approver. Possible options are `User` and `Group`.
        """
        pulumi.set(__self__, "object_id", object_id)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="objectId")
    def object_id(self) -> pulumi.Input[str]:
        """
        The ID of the object which will act as an approver.
        """
        return pulumi.get(self, "object_id")

    @object_id.setter
    def object_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "object_id", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The type of object acting as an approver. Possible options are `User` and `Group`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)


if not MYPY:
    class RoleManagementPolicyActiveAssignmentRulesArgsDict(TypedDict):
        expiration_required: NotRequired[pulumi.Input[bool]]
        """
        Must an assignment have an expiry date. `false` allows permanent assignment.
        """
        expire_after: NotRequired[pulumi.Input[str]]
        """
        The maximum length of time an assignment can be valid, as an ISO8601 duration. Permitted values: `P15D`, `P30D`, `P90D`, `P180D`, or `P365D`.
        """
        require_justification: NotRequired[pulumi.Input[bool]]
        """
        Is a justification required to create new assignments.
        """
        require_multifactor_authentication: NotRequired[pulumi.Input[bool]]
        """
        Is multi-factor authentication required to create new assignments.
        """
        require_ticket_info: NotRequired[pulumi.Input[bool]]
        """
        Is ticket information required to create new assignments.

        One of `expiration_required` or `expire_after` must be provided.
        """
elif False:
    RoleManagementPolicyActiveAssignmentRulesArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyActiveAssignmentRulesArgs:
    def __init__(__self__, *,
                 expiration_required: Optional[pulumi.Input[bool]] = None,
                 expire_after: Optional[pulumi.Input[str]] = None,
                 require_justification: Optional[pulumi.Input[bool]] = None,
                 require_multifactor_authentication: Optional[pulumi.Input[bool]] = None,
                 require_ticket_info: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[bool] expiration_required: Must an assignment have an expiry date. `false` allows permanent assignment.
        :param pulumi.Input[str] expire_after: The maximum length of time an assignment can be valid, as an ISO8601 duration. Permitted values: `P15D`, `P30D`, `P90D`, `P180D`, or `P365D`.
        :param pulumi.Input[bool] require_justification: Is a justification required to create new assignments.
        :param pulumi.Input[bool] require_multifactor_authentication: Is multi-factor authentication required to create new assignments.
        :param pulumi.Input[bool] require_ticket_info: Is ticket information required to create new assignments.
               
               One of `expiration_required` or `expire_after` must be provided.
        """
        if expiration_required is not None:
            pulumi.set(__self__, "expiration_required", expiration_required)
        if expire_after is not None:
            pulumi.set(__self__, "expire_after", expire_after)
        if require_justification is not None:
            pulumi.set(__self__, "require_justification", require_justification)
        if require_multifactor_authentication is not None:
            pulumi.set(__self__, "require_multifactor_authentication", require_multifactor_authentication)
        if require_ticket_info is not None:
            pulumi.set(__self__, "require_ticket_info", require_ticket_info)

    @property
    @pulumi.getter(name="expirationRequired")
    def expiration_required(self) -> Optional[pulumi.Input[bool]]:
        """
        Must an assignment have an expiry date. `false` allows permanent assignment.
        """
        return pulumi.get(self, "expiration_required")

    @expiration_required.setter
    def expiration_required(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expiration_required", value)

    @property
    @pulumi.getter(name="expireAfter")
    def expire_after(self) -> Optional[pulumi.Input[str]]:
        """
        The maximum length of time an assignment can be valid, as an ISO8601 duration. Permitted values: `P15D`, `P30D`, `P90D`, `P180D`, or `P365D`.
        """
        return pulumi.get(self, "expire_after")

    @expire_after.setter
    def expire_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expire_after", value)

    @property
    @pulumi.getter(name="requireJustification")
    def require_justification(self) -> Optional[pulumi.Input[bool]]:
        """
        Is a justification required to create new assignments.
        """
        return pulumi.get(self, "require_justification")

    @require_justification.setter
    def require_justification(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "require_justification", value)

    @property
    @pulumi.getter(name="requireMultifactorAuthentication")
    def require_multifactor_authentication(self) -> Optional[pulumi.Input[bool]]:
        """
        Is multi-factor authentication required to create new assignments.
        """
        return pulumi.get(self, "require_multifactor_authentication")

    @require_multifactor_authentication.setter
    def require_multifactor_authentication(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "require_multifactor_authentication", value)

    @property
    @pulumi.getter(name="requireTicketInfo")
    def require_ticket_info(self) -> Optional[pulumi.Input[bool]]:
        """
        Is ticket information required to create new assignments.

        One of `expiration_required` or `expire_after` must be provided.
        """
        return pulumi.get(self, "require_ticket_info")

    @require_ticket_info.setter
    def require_ticket_info(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "require_ticket_info", value)


if not MYPY:
    class RoleManagementPolicyEligibleAssignmentRulesArgsDict(TypedDict):
        expiration_required: NotRequired[pulumi.Input[bool]]
        """
        Must an assignment have an expiry date. `false` allows permanent assignment.
        """
        expire_after: NotRequired[pulumi.Input[str]]
        """
        The maximum length of time an assignment can be valid, as an ISO8601 duration. Permitted values: `P15D`, `P30D`, `P90D`, `P180D`, or `P365D`.

        One of `expiration_required` or `expire_after` must be provided.
        """
elif False:
    RoleManagementPolicyEligibleAssignmentRulesArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyEligibleAssignmentRulesArgs:
    def __init__(__self__, *,
                 expiration_required: Optional[pulumi.Input[bool]] = None,
                 expire_after: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[bool] expiration_required: Must an assignment have an expiry date. `false` allows permanent assignment.
        :param pulumi.Input[str] expire_after: The maximum length of time an assignment can be valid, as an ISO8601 duration. Permitted values: `P15D`, `P30D`, `P90D`, `P180D`, or `P365D`.
               
               One of `expiration_required` or `expire_after` must be provided.
        """
        if expiration_required is not None:
            pulumi.set(__self__, "expiration_required", expiration_required)
        if expire_after is not None:
            pulumi.set(__self__, "expire_after", expire_after)

    @property
    @pulumi.getter(name="expirationRequired")
    def expiration_required(self) -> Optional[pulumi.Input[bool]]:
        """
        Must an assignment have an expiry date. `false` allows permanent assignment.
        """
        return pulumi.get(self, "expiration_required")

    @expiration_required.setter
    def expiration_required(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expiration_required", value)

    @property
    @pulumi.getter(name="expireAfter")
    def expire_after(self) -> Optional[pulumi.Input[str]]:
        """
        The maximum length of time an assignment can be valid, as an ISO8601 duration. Permitted values: `P15D`, `P30D`, `P90D`, `P180D`, or `P365D`.

        One of `expiration_required` or `expire_after` must be provided.
        """
        return pulumi.get(self, "expire_after")

    @expire_after.setter
    def expire_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expire_after", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesArgsDict(TypedDict):
        active_assignments: NotRequired[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsArgsDict']]
        """
        A `notification_target` block as defined below to configure notfications on active role assignments.
        """
        eligible_activations: NotRequired[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsArgsDict']]
        """
        A `notification_target` block as defined below for configuring notifications on activation of eligible role.
        """
        eligible_assignments: NotRequired[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsArgsDict']]
        """
        A `notification_target` block as defined below to configure notification on eligible role assignments.

        At least one `notification_target` block must be provided.
        """
elif False:
    RoleManagementPolicyNotificationRulesArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesArgs:
    def __init__(__self__, *,
                 active_assignments: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsArgs']] = None,
                 eligible_activations: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsArgs']] = None,
                 eligible_assignments: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsArgs']] = None):
        """
        :param pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsArgs'] active_assignments: A `notification_target` block as defined below to configure notfications on active role assignments.
        :param pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsArgs'] eligible_activations: A `notification_target` block as defined below for configuring notifications on activation of eligible role.
        :param pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsArgs'] eligible_assignments: A `notification_target` block as defined below to configure notification on eligible role assignments.
               
               At least one `notification_target` block must be provided.
        """
        if active_assignments is not None:
            pulumi.set(__self__, "active_assignments", active_assignments)
        if eligible_activations is not None:
            pulumi.set(__self__, "eligible_activations", eligible_activations)
        if eligible_assignments is not None:
            pulumi.set(__self__, "eligible_assignments", eligible_assignments)

    @property
    @pulumi.getter(name="activeAssignments")
    def active_assignments(self) -> Optional[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsArgs']]:
        """
        A `notification_target` block as defined below to configure notfications on active role assignments.
        """
        return pulumi.get(self, "active_assignments")

    @active_assignments.setter
    def active_assignments(self, value: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsArgs']]):
        pulumi.set(self, "active_assignments", value)

    @property
    @pulumi.getter(name="eligibleActivations")
    def eligible_activations(self) -> Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsArgs']]:
        """
        A `notification_target` block as defined below for configuring notifications on activation of eligible role.
        """
        return pulumi.get(self, "eligible_activations")

    @eligible_activations.setter
    def eligible_activations(self, value: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsArgs']]):
        pulumi.set(self, "eligible_activations", value)

    @property
    @pulumi.getter(name="eligibleAssignments")
    def eligible_assignments(self) -> Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsArgs']]:
        """
        A `notification_target` block as defined below to configure notification on eligible role assignments.

        At least one `notification_target` block must be provided.
        """
        return pulumi.get(self, "eligible_assignments")

    @eligible_assignments.setter
    def eligible_assignments(self, value: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsArgs']]):
        pulumi.set(self, "eligible_assignments", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesActiveAssignmentsArgsDict(TypedDict):
        admin_notifications: NotRequired[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotificationsArgsDict']]
        """
        Admin notification settings
        """
        approver_notifications: NotRequired[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotificationsArgsDict']]
        """
        Approver notification settings
        """
        assignee_notifications: NotRequired[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotificationsArgsDict']]
        """
        Assignee notification settings
        """
elif False:
    RoleManagementPolicyNotificationRulesActiveAssignmentsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesActiveAssignmentsArgs:
    def __init__(__self__, *,
                 admin_notifications: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotificationsArgs']] = None,
                 approver_notifications: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotificationsArgs']] = None,
                 assignee_notifications: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotificationsArgs']] = None):
        """
        :param pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotificationsArgs'] admin_notifications: Admin notification settings
        :param pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotificationsArgs'] approver_notifications: Approver notification settings
        :param pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotificationsArgs'] assignee_notifications: Assignee notification settings
        """
        if admin_notifications is not None:
            pulumi.set(__self__, "admin_notifications", admin_notifications)
        if approver_notifications is not None:
            pulumi.set(__self__, "approver_notifications", approver_notifications)
        if assignee_notifications is not None:
            pulumi.set(__self__, "assignee_notifications", assignee_notifications)

    @property
    @pulumi.getter(name="adminNotifications")
    def admin_notifications(self) -> Optional[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotificationsArgs']]:
        """
        Admin notification settings
        """
        return pulumi.get(self, "admin_notifications")

    @admin_notifications.setter
    def admin_notifications(self, value: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotificationsArgs']]):
        pulumi.set(self, "admin_notifications", value)

    @property
    @pulumi.getter(name="approverNotifications")
    def approver_notifications(self) -> Optional[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotificationsArgs']]:
        """
        Approver notification settings
        """
        return pulumi.get(self, "approver_notifications")

    @approver_notifications.setter
    def approver_notifications(self, value: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotificationsArgs']]):
        pulumi.set(self, "approver_notifications", value)

    @property
    @pulumi.getter(name="assigneeNotifications")
    def assignee_notifications(self) -> Optional[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotificationsArgs']]:
        """
        Assignee notification settings
        """
        return pulumi.get(self, "assignee_notifications")

    @assignee_notifications.setter
    def assignee_notifications(self, value: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotificationsArgs']]):
        pulumi.set(self, "assignee_notifications", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotificationsArgsDict(TypedDict):
        default_recipients: pulumi.Input[bool]
        """
        Whether the default recipients are notified
        """
        notification_level: pulumi.Input[str]
        """
        What level of notifications are sent
        """
        additional_recipients: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The additional recipients to notify
        """
elif False:
    RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotificationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotificationsArgs:
    def __init__(__self__, *,
                 default_recipients: pulumi.Input[bool],
                 notification_level: pulumi.Input[str],
                 additional_recipients: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[bool] default_recipients: Whether the default recipients are notified
        :param pulumi.Input[str] notification_level: What level of notifications are sent
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> pulumi.Input[bool]:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @default_recipients.setter
    def default_recipients(self, value: pulumi.Input[bool]):
        pulumi.set(self, "default_recipients", value)

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> pulumi.Input[str]:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @notification_level.setter
    def notification_level(self, value: pulumi.Input[str]):
        pulumi.set(self, "notification_level", value)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")

    @additional_recipients.setter
    def additional_recipients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_recipients", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotificationsArgsDict(TypedDict):
        default_recipients: pulumi.Input[bool]
        """
        Whether the default recipients are notified
        """
        notification_level: pulumi.Input[str]
        """
        What level of notifications are sent
        """
        additional_recipients: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The additional recipients to notify
        """
elif False:
    RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotificationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotificationsArgs:
    def __init__(__self__, *,
                 default_recipients: pulumi.Input[bool],
                 notification_level: pulumi.Input[str],
                 additional_recipients: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[bool] default_recipients: Whether the default recipients are notified
        :param pulumi.Input[str] notification_level: What level of notifications are sent
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> pulumi.Input[bool]:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @default_recipients.setter
    def default_recipients(self, value: pulumi.Input[bool]):
        pulumi.set(self, "default_recipients", value)

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> pulumi.Input[str]:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @notification_level.setter
    def notification_level(self, value: pulumi.Input[str]):
        pulumi.set(self, "notification_level", value)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")

    @additional_recipients.setter
    def additional_recipients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_recipients", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotificationsArgsDict(TypedDict):
        default_recipients: pulumi.Input[bool]
        """
        Whether the default recipients are notified
        """
        notification_level: pulumi.Input[str]
        """
        What level of notifications are sent
        """
        additional_recipients: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The additional recipients to notify
        """
elif False:
    RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotificationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotificationsArgs:
    def __init__(__self__, *,
                 default_recipients: pulumi.Input[bool],
                 notification_level: pulumi.Input[str],
                 additional_recipients: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[bool] default_recipients: Whether the default recipients are notified
        :param pulumi.Input[str] notification_level: What level of notifications are sent
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> pulumi.Input[bool]:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @default_recipients.setter
    def default_recipients(self, value: pulumi.Input[bool]):
        pulumi.set(self, "default_recipients", value)

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> pulumi.Input[str]:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @notification_level.setter
    def notification_level(self, value: pulumi.Input[str]):
        pulumi.set(self, "notification_level", value)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")

    @additional_recipients.setter
    def additional_recipients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_recipients", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesEligibleActivationsArgsDict(TypedDict):
        admin_notifications: NotRequired[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotificationsArgsDict']]
        """
        Admin notification settings
        """
        approver_notifications: NotRequired[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotificationsArgsDict']]
        """
        Approver notification settings
        """
        assignee_notifications: NotRequired[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotificationsArgsDict']]
        """
        Assignee notification settings
        """
elif False:
    RoleManagementPolicyNotificationRulesEligibleActivationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesEligibleActivationsArgs:
    def __init__(__self__, *,
                 admin_notifications: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotificationsArgs']] = None,
                 approver_notifications: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotificationsArgs']] = None,
                 assignee_notifications: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotificationsArgs']] = None):
        """
        :param pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotificationsArgs'] admin_notifications: Admin notification settings
        :param pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotificationsArgs'] approver_notifications: Approver notification settings
        :param pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotificationsArgs'] assignee_notifications: Assignee notification settings
        """
        if admin_notifications is not None:
            pulumi.set(__self__, "admin_notifications", admin_notifications)
        if approver_notifications is not None:
            pulumi.set(__self__, "approver_notifications", approver_notifications)
        if assignee_notifications is not None:
            pulumi.set(__self__, "assignee_notifications", assignee_notifications)

    @property
    @pulumi.getter(name="adminNotifications")
    def admin_notifications(self) -> Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotificationsArgs']]:
        """
        Admin notification settings
        """
        return pulumi.get(self, "admin_notifications")

    @admin_notifications.setter
    def admin_notifications(self, value: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotificationsArgs']]):
        pulumi.set(self, "admin_notifications", value)

    @property
    @pulumi.getter(name="approverNotifications")
    def approver_notifications(self) -> Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotificationsArgs']]:
        """
        Approver notification settings
        """
        return pulumi.get(self, "approver_notifications")

    @approver_notifications.setter
    def approver_notifications(self, value: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotificationsArgs']]):
        pulumi.set(self, "approver_notifications", value)

    @property
    @pulumi.getter(name="assigneeNotifications")
    def assignee_notifications(self) -> Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotificationsArgs']]:
        """
        Assignee notification settings
        """
        return pulumi.get(self, "assignee_notifications")

    @assignee_notifications.setter
    def assignee_notifications(self, value: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotificationsArgs']]):
        pulumi.set(self, "assignee_notifications", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotificationsArgsDict(TypedDict):
        default_recipients: pulumi.Input[bool]
        """
        Whether the default recipients are notified
        """
        notification_level: pulumi.Input[str]
        """
        What level of notifications are sent
        """
        additional_recipients: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The additional recipients to notify
        """
elif False:
    RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotificationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotificationsArgs:
    def __init__(__self__, *,
                 default_recipients: pulumi.Input[bool],
                 notification_level: pulumi.Input[str],
                 additional_recipients: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[bool] default_recipients: Whether the default recipients are notified
        :param pulumi.Input[str] notification_level: What level of notifications are sent
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> pulumi.Input[bool]:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @default_recipients.setter
    def default_recipients(self, value: pulumi.Input[bool]):
        pulumi.set(self, "default_recipients", value)

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> pulumi.Input[str]:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @notification_level.setter
    def notification_level(self, value: pulumi.Input[str]):
        pulumi.set(self, "notification_level", value)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")

    @additional_recipients.setter
    def additional_recipients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_recipients", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotificationsArgsDict(TypedDict):
        default_recipients: pulumi.Input[bool]
        """
        Whether the default recipients are notified
        """
        notification_level: pulumi.Input[str]
        """
        What level of notifications are sent
        """
        additional_recipients: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The additional recipients to notify
        """
elif False:
    RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotificationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotificationsArgs:
    def __init__(__self__, *,
                 default_recipients: pulumi.Input[bool],
                 notification_level: pulumi.Input[str],
                 additional_recipients: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[bool] default_recipients: Whether the default recipients are notified
        :param pulumi.Input[str] notification_level: What level of notifications are sent
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> pulumi.Input[bool]:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @default_recipients.setter
    def default_recipients(self, value: pulumi.Input[bool]):
        pulumi.set(self, "default_recipients", value)

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> pulumi.Input[str]:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @notification_level.setter
    def notification_level(self, value: pulumi.Input[str]):
        pulumi.set(self, "notification_level", value)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")

    @additional_recipients.setter
    def additional_recipients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_recipients", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotificationsArgsDict(TypedDict):
        default_recipients: pulumi.Input[bool]
        """
        Whether the default recipients are notified
        """
        notification_level: pulumi.Input[str]
        """
        What level of notifications are sent
        """
        additional_recipients: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The additional recipients to notify
        """
elif False:
    RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotificationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotificationsArgs:
    def __init__(__self__, *,
                 default_recipients: pulumi.Input[bool],
                 notification_level: pulumi.Input[str],
                 additional_recipients: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[bool] default_recipients: Whether the default recipients are notified
        :param pulumi.Input[str] notification_level: What level of notifications are sent
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> pulumi.Input[bool]:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @default_recipients.setter
    def default_recipients(self, value: pulumi.Input[bool]):
        pulumi.set(self, "default_recipients", value)

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> pulumi.Input[str]:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @notification_level.setter
    def notification_level(self, value: pulumi.Input[str]):
        pulumi.set(self, "notification_level", value)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")

    @additional_recipients.setter
    def additional_recipients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_recipients", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesEligibleAssignmentsArgsDict(TypedDict):
        admin_notifications: NotRequired[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotificationsArgsDict']]
        """
        Admin notification settings
        """
        approver_notifications: NotRequired[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotificationsArgsDict']]
        """
        Approver notification settings
        """
        assignee_notifications: NotRequired[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotificationsArgsDict']]
        """
        Assignee notification settings
        """
elif False:
    RoleManagementPolicyNotificationRulesEligibleAssignmentsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesEligibleAssignmentsArgs:
    def __init__(__self__, *,
                 admin_notifications: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotificationsArgs']] = None,
                 approver_notifications: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotificationsArgs']] = None,
                 assignee_notifications: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotificationsArgs']] = None):
        """
        :param pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotificationsArgs'] admin_notifications: Admin notification settings
        :param pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotificationsArgs'] approver_notifications: Approver notification settings
        :param pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotificationsArgs'] assignee_notifications: Assignee notification settings
        """
        if admin_notifications is not None:
            pulumi.set(__self__, "admin_notifications", admin_notifications)
        if approver_notifications is not None:
            pulumi.set(__self__, "approver_notifications", approver_notifications)
        if assignee_notifications is not None:
            pulumi.set(__self__, "assignee_notifications", assignee_notifications)

    @property
    @pulumi.getter(name="adminNotifications")
    def admin_notifications(self) -> Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotificationsArgs']]:
        """
        Admin notification settings
        """
        return pulumi.get(self, "admin_notifications")

    @admin_notifications.setter
    def admin_notifications(self, value: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotificationsArgs']]):
        pulumi.set(self, "admin_notifications", value)

    @property
    @pulumi.getter(name="approverNotifications")
    def approver_notifications(self) -> Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotificationsArgs']]:
        """
        Approver notification settings
        """
        return pulumi.get(self, "approver_notifications")

    @approver_notifications.setter
    def approver_notifications(self, value: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotificationsArgs']]):
        pulumi.set(self, "approver_notifications", value)

    @property
    @pulumi.getter(name="assigneeNotifications")
    def assignee_notifications(self) -> Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotificationsArgs']]:
        """
        Assignee notification settings
        """
        return pulumi.get(self, "assignee_notifications")

    @assignee_notifications.setter
    def assignee_notifications(self, value: Optional[pulumi.Input['RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotificationsArgs']]):
        pulumi.set(self, "assignee_notifications", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotificationsArgsDict(TypedDict):
        default_recipients: pulumi.Input[bool]
        """
        Whether the default recipients are notified
        """
        notification_level: pulumi.Input[str]
        """
        What level of notifications are sent
        """
        additional_recipients: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The additional recipients to notify
        """
elif False:
    RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotificationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotificationsArgs:
    def __init__(__self__, *,
                 default_recipients: pulumi.Input[bool],
                 notification_level: pulumi.Input[str],
                 additional_recipients: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[bool] default_recipients: Whether the default recipients are notified
        :param pulumi.Input[str] notification_level: What level of notifications are sent
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> pulumi.Input[bool]:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @default_recipients.setter
    def default_recipients(self, value: pulumi.Input[bool]):
        pulumi.set(self, "default_recipients", value)

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> pulumi.Input[str]:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @notification_level.setter
    def notification_level(self, value: pulumi.Input[str]):
        pulumi.set(self, "notification_level", value)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")

    @additional_recipients.setter
    def additional_recipients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_recipients", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotificationsArgsDict(TypedDict):
        default_recipients: pulumi.Input[bool]
        """
        Whether the default recipients are notified
        """
        notification_level: pulumi.Input[str]
        """
        What level of notifications are sent
        """
        additional_recipients: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The additional recipients to notify
        """
elif False:
    RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotificationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotificationsArgs:
    def __init__(__self__, *,
                 default_recipients: pulumi.Input[bool],
                 notification_level: pulumi.Input[str],
                 additional_recipients: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[bool] default_recipients: Whether the default recipients are notified
        :param pulumi.Input[str] notification_level: What level of notifications are sent
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> pulumi.Input[bool]:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @default_recipients.setter
    def default_recipients(self, value: pulumi.Input[bool]):
        pulumi.set(self, "default_recipients", value)

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> pulumi.Input[str]:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @notification_level.setter
    def notification_level(self, value: pulumi.Input[str]):
        pulumi.set(self, "notification_level", value)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")

    @additional_recipients.setter
    def additional_recipients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_recipients", value)


if not MYPY:
    class RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotificationsArgsDict(TypedDict):
        default_recipients: pulumi.Input[bool]
        """
        Whether the default recipients are notified
        """
        notification_level: pulumi.Input[str]
        """
        What level of notifications are sent
        """
        additional_recipients: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The additional recipients to notify
        """
elif False:
    RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotificationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotificationsArgs:
    def __init__(__self__, *,
                 default_recipients: pulumi.Input[bool],
                 notification_level: pulumi.Input[str],
                 additional_recipients: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[bool] default_recipients: Whether the default recipients are notified
        :param pulumi.Input[str] notification_level: What level of notifications are sent
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> pulumi.Input[bool]:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @default_recipients.setter
    def default_recipients(self, value: pulumi.Input[bool]):
        pulumi.set(self, "default_recipients", value)

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> pulumi.Input[str]:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @notification_level.setter
    def notification_level(self, value: pulumi.Input[str]):
        pulumi.set(self, "notification_level", value)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")

    @additional_recipients.setter
    def additional_recipients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_recipients", value)


